package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.BareMetalInstances;

/**
 * 定制裸金属服务Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface BareMetalInstancesMapper 
{
    /**
     * 查询定制裸金属服务
     * 
     * @param id 定制裸金属服务主键
     * @return 定制裸金属服务
     */
    public BareMetalInstances selectBareMetalInstancesById(Integer id);

    /**
     * 查询定制裸金属服务列表
     * 
     * @param bareMetalInstances 定制裸金属服务
     * @return 定制裸金属服务集合
     */
    public List<BareMetalInstances> selectBareMetalInstancesList(BareMetalInstances bareMetalInstances);

    /**
     * 新增定制裸金属服务
     * 
     * @param bareMetalInstances 定制裸金属服务
     * @return 结果
     */
    public int insertBareMetalInstances(BareMetalInstances bareMetalInstances);

    /**
     * 修改定制裸金属服务
     * 
     * @param bareMetalInstances 定制裸金属服务
     * @return 结果
     */
    public int updateBareMetalInstances(BareMetalInstances bareMetalInstances);

    /**
     * 删除定制裸金属服务
     * 
     * @param id 定制裸金属服务主键
     * @return 结果
     */
    public int deleteBareMetalInstancesById(Integer id);

    /**
     * 批量删除定制裸金属服务
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBareMetalInstancesByIds(Integer[] ids);
}
